# Silly Algorithm for Badger

Just a super silly random search optimization algorithm. The sole usage of this is to demo the functionality of Badger's algorithm plugin system.

## Prerequisites

## Usage
